@@ -1,9 +1,7 @@
 #!/usr/bin/env python
 
-# Author: David Goodger
-# Contact: goodger@python.org
-# Revision:  $Revision: 3039 $
-# Date:      $Date: 2005-03-14 17:45:09 +0100 (Mon, 14 Mar 2005) $
+# $Id: test_settings.py 7400 2012-05-01 08:34:41Z grubert $
+# Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
@@ -12,11 +10,11 @@ Tests of runtime settings.
 
 import sys
 import os
-import docutils_difflib
+import difflib
 import pprint
 import warnings
 import unittest
-from types import StringType
+import DocutilsTestSupport              # must be imported before docutils
 from docutils import frontend, utils
 from docutils.writers import html4css1, pep_html
 from docutils.parsers import rst
@@ -25,10 +23,14 @@ from docutils.parsers import rst
 warnings.filterwarnings(action='ignore',
                         category=frontend.ConfigDeprecationWarning)
 
-def fixpath(path):
-    return os.path.abspath(os.path.join(mydir, path))
+# python 2.3
+if not hasattr(unittest.TestCase, "assertTrue"):
+    # HACK? this changes TestCase, fixes the problem for tests executing afterwards.
+    # this tests break if run alone
+    unittest.TestCase.assertTrue = unittest.TestCase.failUnless
 
-mydir = os.path.dirname(fixpath.func_code.co_filename)
+def fixpath(path):
+    return os.path.abspath(os.path.join(*(path.split('/'))))
 
 
 class ConfigFileTests(unittest.TestCase):
@@ -41,37 +43,47 @@ class ConfigFileTests(unittest.TestCase):
                     'error': fixpath('data/config_error_handler.txt')}
 
     settings = {
-        'old': {'datestamp': '%Y-%m-%d %H:%M UTC',
-                'generator': 1,
-                'no_random': 1,
-                'python_home': 'http://www.python.org',
-                'source_link': 1,
+        'old': {u'datestamp': u'%Y-%m-%d %H:%M UTC',
+                u'generator': 1,
+                u'no_random': 1,
+                u'python_home': u'http://www.python.org',
+                u'source_link': 1,
                 'stylesheet': None,
-                'stylesheet_path': fixpath('data/stylesheets/pep.css'),
-                'template': fixpath('data/pep-html-template')},
-        'one': {'datestamp': '%Y-%m-%d %H:%M UTC',
-                'generator': 1,
-                'no_random': 1,
-                'python_home': 'http://www.python.org',
+                u'stylesheet_path': fixpath(u'data/stylesheets/pep.css'),
+                'template': fixpath(u'data/pep-html-template')},
+        'one': {u'datestamp': u'%Y-%m-%d %H:%M UTC',
+                u'generator': 1,
+                u'no_random': 1,
+                u'python_home': u'http://www.python.org',
+                u'raw_enabled': 0,
                 'record_dependencies': utils.DependencyList(),
-                'source_link': 1,
+                u'source_link': 1,
                 'stylesheet': None,
-                'stylesheet_path': fixpath('data/stylesheets/pep.css'),
-                'template': fixpath('data/pep-html-template'),
-                'trim_footnote_reference_space': 1},
-        'two': {'footnote_references': 'superscript',
-                'generator': 0,
+                u'stylesheet_path': fixpath(u'data/stylesheets/pep.css'),
+                u'tab_width': 8,
+                u'template': fixpath(u'data/pep-html-template'),
+                u'trim_footnote_reference_space': 1},
+        'two': {u'footnote_references': u'superscript',
+                u'generator': 0,
                 'record_dependencies': utils.DependencyList(),
-                'stylesheet': None,
-                'stylesheet_path': fixpath('data/test.css'),
+                u'stylesheet': None,
+                u'stylesheet_path': fixpath(u'data/test.css'),
                 'trim_footnote_reference_space': None},
-        'list': {'expose_internals': ['a', 'b', 'c', 'd', 'e']},
-        'list2': {'expose_internals': ['a', 'b', 'c', 'd', 'e', 'f']},
-        'error': {'error_encoding': 'ascii',
-                  'error_encoding_error_handler': 'strict'},
+        'list': {u'expose_internals': [u'a', u'b', u'c', u'd', u'e'],
+                 u'strip_classes': [u'spam', u'pan', u'fun', u'parrot'],
+                 u'strip_elements_with_classes': [u'sugar', u'flour', u'milk',
+                                                  u'safran']},
+        'list2': {u'expose_internals': [u'a', u'b', u'c', u'd', u'e', u'f'],
+                  u'strip_classes': [u'spam', u'pan', u'fun', u'parrot',
+                                     u'ham', u'eggs'],
+                  u'strip_elements_with_classes': [u'sugar', u'flour',
+                                                   u'milk', u'safran',
+                                                   u'eggs', u'salt']},
+        'error': {u'error_encoding': u'ascii',
+                  u'error_encoding_error_handler': u'strict'},
         }
 
-    compare = docutils_difflib.Differ().compare
+    compare = difflib.Differ().compare
     """Comparison method shared by all tests."""
 
     def setUp(self):
@@ -93,14 +105,14 @@ class ConfigFileTests(unittest.TestCase):
 
     def compare_output(self, result, expected):
         """`result` and `expected` should both be dicts."""
-        self.assert_(result.has_key('record_dependencies'))
-        if not expected.has_key('record_dependencies'):
+        self.assertTrue('record_dependencies' in result)
+        if 'record_dependencies' not in expected:
             # Delete it if we don't want to test it.
             del result['record_dependencies']
         result = pprint.pformat(result) + '\n'
         expected = pprint.pformat(expected) + '\n'
         try:
-            self.assertEquals(result, expected)
+            self.assertEqual(result, expected)
         except AssertionError:
             print >>sys.stderr, '\n%s\n' % (self,)
             print >>sys.stderr, '-: expected\n+: result'
@@ -163,5 +175,29 @@ class ConfigEnvVarFileTests(ConfigFileTests):
         os.environ = self.orig_environ
 
 
+class HelperFunctionsTests(unittest.TestCase):
+
+    pathdict = {'foo': 'hallo', 'ham': u'h\xE4m', 'spam': u'spam'}
+    keys = ['foo', 'ham']
+
+    def test_make_paths_absolute(self):
+        pathdict = self.pathdict.copy()
+        frontend.make_paths_absolute(pathdict, self.keys, base_path='base')
+        self.assertEqual(pathdict['foo'], os.path.abspath('base/hallo'))
+        self.assertEqual(pathdict['ham'], os.path.abspath(u'base/h\xE4m'))
+        # not touched, because key not in keys:
+        self.assertEqual(pathdict['spam'], u'spam')
+
+    def test_make_paths_absolute_cwd(self):
+        # With base_path None, the cwd is used as base path.
+        # Settings values may-be `unicode` instances, therefore
+        # os.getcwdu() is used and the converted path is a unicode instance:
+        pathdict = self.pathdict.copy()
+        frontend.make_paths_absolute(pathdict, self.keys)
+        self.assertEqual(pathdict['foo'], os.path.abspath(u'hallo'))
+        self.assertEqual(pathdict['ham'], os.path.abspath(u'h\xE4m'))
+        # not touched, because key not in keys:
+        self.assertEqual(pathdict['spam'], u'spam')
+
 if __name__ == '__main__':
     unittest.main()
