@@ -1,9 +1,7 @@
 #!/usr/bin/env python
 
-# Author: David Goodger
-# Contact: goodger@users.sourceforge.net
-# Revision: $Revision: 2504 $
-# Date: $Date: 2004-07-29 06:36:53 +0200 (Thu, 29 Jul 2004) $
+# $Id: buildhtml.py 7442 2012-06-13 23:27:03Z milde $
+# Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
@@ -27,9 +25,11 @@ import sys
 import os
 import os.path
 import copy
+from fnmatch import fnmatch
 import docutils
 from docutils import ApplicationError
-from docutils import core, frontend
+from docutils import core, frontend, utils
+from docutils.error_reporting import ErrorOutput, ErrorString
 from docutils.parsers import rst
 from docutils.readers import standalone, pep
 from docutils.writers import html4css1, pep_html
@@ -47,6 +47,8 @@ class SettingsSpec(docutils.SettingsSpec):
     Runtime settings & command-line options for the front end.
     """
 
+    prune_default = ['.hg', '.bzr', '.git', '.svn', 'CVS']
+
     # Can't be included in OptionParser below because we don't want to
     # override the base class.
     settings_spec = (
@@ -59,13 +61,25 @@ class SettingsSpec(docutils.SettingsSpec):
            'validator': frontend.validate_boolean}),
          ('Do not scan subdirectories for files to process.',
           ['--local'], {'dest': 'recurse', 'action': 'store_false'}),
-         ('Do not process files in <directory>.  This option may be used '
-          'more than once to specify multiple directories.',
+         ('Do not process files in <directory> (shell globbing patterns, '
+          'separated by colons).  This option may be used '
+          'more than once to specify multiple directories.  Default: "%s".'
+          % ':'.join(prune_default),
           ['--prune'],
           {'metavar': '<directory>', 'action': 'append',
+           'validator': frontend.validate_colon_separated_string_list,
+           'default': prune_default,}),
+         ('Recursively ignore files matching any of the given '
+          'wildcard (shell globbing) patterns (separated by colons).',
+          ['--ignore'],
+          {'metavar': '<patterns>', 'action': 'append',
+           'default': [],
            'validator': frontend.validate_colon_separated_string_list}),
          ('Work silently (no progress messages).  Independent of "--quiet".',
           ['--silent'],
+          {'action': 'store_true', 'validator': frontend.validate_boolean}),
+         ('Do not process files, show files that would be processed.',
+          ['--dry-run'],
           {'action': 'store_true', 'validator': frontend.validate_boolean}),))
 
     relative_path_settings = ('prune',)
@@ -175,26 +189,35 @@ class Builder:
         else:
             self.directories = [os.getcwd()]
         for directory in self.directories:
-            os.path.walk(directory, self.visit, recurse)
+            for root, dirs, files in os.walk(directory):
+                # os.walk by default this recurses down the tree,
+                # influence by modifying dirs.
+                if not recurse:
+                    del dirs[:]
+                self.visit(root, files, dirs)
 
-    def visit(self, recurse, directory, names):
+    def visit(self, directory, names, subdirectories):
         settings = self.get_settings('', directory)
+        errout = ErrorOutput(encoding=settings.error_encoding)
         if settings.prune and (os.path.abspath(directory) in settings.prune):
-            print >>sys.stderr, '/// ...Skipping directory (pruned):', directory
+            errout.write('/// ...Skipping directory (pruned): %s\n' %
+                         directory)
             sys.stderr.flush()
-            names[:] = []
+            del subdirectories[:]
             return
         if not self.initial_settings.silent:
-            print >>sys.stderr, '/// Processing directory:', directory
+            errout.write('/// Processing directory: %s' % directory)
             sys.stderr.flush()
-        prune = 0
+        # settings.ignore grows many duplicate entries as we recurse
+        # if we add patterns in config files or on the command line.
+        for pattern in utils.uniq(settings.ignore):
+            for i in range(len(names) - 1, -1, -1):
+                if fnmatch(names[i], pattern):
+                    # Modify in place!
+                    del names[i]
         for name in names:
             if name.endswith('.txt'):
-                prune = self.process_txt(directory, name)
-                if prune:
-                    break
-        if not recurse:
-            del names[:]
+                self.process_txt(directory, name)
 
     def process_txt(self, directory, name):
         if name.startswith('pep-'):
@@ -202,24 +225,24 @@ class Builder:
         else:
             publisher = '.txt'
         settings = self.get_settings(publisher, directory)
+        errout = ErrorOutput(encoding=settings.error_encoding)
         pub_struct = self.publishers[publisher]
-        if settings.prune and (directory in settings.prune):
-            return 1
         settings._source = os.path.normpath(os.path.join(directory, name))
         settings._destination = settings._source[:-4]+'.html'
         if not self.initial_settings.silent:
-            print >>sys.stderr, '    ::: Processing:', name
+            errout.write('    ::: Processing: %s\n' % name)
             sys.stderr.flush()
         try:
-            core.publish_file(source_path=settings._source,
+            if not settings.dry_run:
+                core.publish_file(source_path=settings._source,
                               destination_path=settings._destination,
                               reader_name=pub_struct.reader_name,
                               parser_name='restructuredtext',
                               writer_name=pub_struct.writer_name,
                               settings=settings)
-        except ApplicationError, error:
-            print >>sys.stderr, ('        Error (%s): %s'
-                                 % (error.__class__.__name__, error))
+        except ApplicationError:
+            error = sys.exc_info()[1] # get exception in Python <2.6 and 3.x
+            errout.write('        %s\n' % ErrorString(error))
 
 
 if __name__ == "__main__":
